@@ -8,7 +8,7 @@ from napari_plugin_engine import napari_hook_implementation
 from ._categories import CATEGORIES
 from ._gui import Assistant
 from ._gui._category_widget import make_gui_for_category
-
+from ._statistics_of_labeled_pixels import statistics_of_labeled_pixels
 
 @napari_hook_implementation
 def napari_experimental_provide_dock_widget():
@@ -26,3 +26,8 @@ def napari_provide_sample_data():
         "CalibZAPW": data / "CalibZAPWfixed_000154_max-16.tif",
         "Sonneberg": data / "Sonneberg100_Resampled_RotY-40_MaxZ.tif",
     }
+
+
+@napari_hook_implementation
+def napari_experimental_provide_function():
+    return [statistics_of_labeled_pixels]
